@@ -1,7 +1,9 @@
 .First.lib <- function(lib, pkg)  {
-  cat(paste("This is dtw",
+  cat(paste("This is dtw ",
             utils::packageDescription("dtw")$Version,
-            "\n"))
+	    ". Please see citation(\"dtw\") on how to cite in publications.",
+	    "\n",
+            sep=""))
   library.dynam("dtw");
   invisible()
 }
